==> izimodal-1.5.1.jar: META-INF/resources/webjars/izimodal/1.5.1/README.md <==
# [iziModal](http://izimodal.dolce.ninja)
[![CDNJS](https://img.shields.io/cdnjs/v/izimodal.svg)](https://cdnjs.com/libraries/izimodal)

Elegant, responsive, flexible and lightweight modal plugin with jQuery.

[**izimodal**.marcelodolce.com](http://izimodal.marcelodolce.com)

![capa](http://i.imgur.com/UneCF3L.gif)

[logo]: http://i.imgur.com/hCYIhep.png "Check icon"

[new]: http://i.imgur.com/41zuVDk.png "New label"
[bug]: http://i.imgur.com/92lu4ln.png "Bug label"

Fast | Responsive | Animated | Lightweight | Customizable | History | Group Mode | Retina
:-----: | :-----: | :-----: | :-----: | :-----: | :-----: | :-----: | :-----: 
![alt text][logo] | ![alt text][logo] | ![alt text][logo] | ![alt text][logo] | ![alt text][logo] | ![alt text][logo] | ![alt text][logo] | ![alt text][logo]


- All modern browsers are supported (Tested in Chrome, Firefox, Opera, Safari, IE9+ and Edge).
- Bugs? create an issue [here](https://github.com/dolce/iziModal/issues).


___
- ### [Changelog](http://izimodal.marcelodolce.com/#Changelog)
- ### [Iframe](http://izimodal.marcelodolce.com/#Iframe)
- ### [Ajax](http://izimodal.marcelodolce.com/#Ajax)
- ### [DataAttributes](http://izimodal.marcelodolce.com/#DataAttributes)
- ### [Options](http://izimodal.marcelodolce.com/#Options)
- ### [Methods](http://izimodal.marcelodolce.com/#Methods)
- ### [Events](http://izimodal.marcelodolce.com/#Events)
- ### [Use](http://izimodal.marcelodolce.com/#Start)
___
#### [CDNJS](https://cdnjs.com/libraries/izimodal)
https://cdnjs.com/libraries/izimodal

#### [npm](https://www.npmjs.com/package/izimodal)
```
npm install izimodal --save
```

#### bower
```
bower install izimodal --save
```

#### [GEM](https://github.com/elitenomad/izimodal)
```
gem install izimodal
```



Donations
---------

If you liked this plugin, you can donate to support it:

- http://izimodal.marcelodolce.com#Donations

==> izimodal-1.6.1.jar: META-INF/resources/webjars/izimodal/1.6.1/README.md <==
# [iziModal](http://izimodal.marcelodolza.com)
[![CDNJS](https://img.shields.io/cdnjs/v/izimodal.svg)](https://cdnjs.com/libraries/izimodal)

Elegant, responsive, flexible and lightweight modal plugin with jQuery.

[**izimodal**.marcelodolza.com](http://izimodal.marcelodolza.com)

![capa](http://i.imgur.com/UneCF3L.gif)

[logo]: http://i.imgur.com/hCYIhep.png "Check icon"

[new]: http://i.imgur.com/41zuVDk.png "New label"
[bug]: http://i.imgur.com/92lu4ln.png "Bug label"

Fast | Responsive | Animated | Lightweight | Customizable | History | Group Mode | Retina
:-----: | :-----: | :-----: | :-----: | :-----: | :-----: | :-----: | :-----: 
![alt text][logo] | ![alt text][logo] | ![alt text][logo] | ![alt text][logo] | ![alt text][logo] | ![alt text][logo] | ![alt text][logo] | ![alt text][logo]


- All modern browsers are supported (Tested in Chrome, Firefox, Opera, Safari, IE9+ and Edge).
- Bugs? create an issue [here](https://github.com/marcelodolza/iziModal/issues).


___
- ### [Changelog](http://izimodal.marcelodolza.com/#Changelog)
- ### [Iframe](http://izimodal.marcelodolza.com/#Iframe)
- ### [Ajax](http://izimodal.marcelodolza.com/#Ajax)
- ### [DataAttributes](http://izimodal.marcelodolza.com/#DataAttributes)
- ### [Options](http://izimodal.marcelodolza.com/#Options)
- ### [Methods](http://izimodal.marcelodolza.com/#Methods)
- ### [Events](http://izimodal.marcelodolza.com/#Events)
- ### [Use](http://izimodal.marcelodolza.com/#Start)
___
#### [CDNJS](https://cdnjs.com/libraries/izimodal)
https://cdnjs.com/libraries/izimodal

#### [npm](https://www.npmjs.com/package/izimodal)
```
npm install izimodal --save
```

#### bower
```
bower install izimodal --save
```

#### [GEM](https://github.com/elitenomad/izimodal)
```
gem install izimodal
```



Donations
---------

If you liked this plugin, you can donate to support it:

- http://izimodal.marcelodolza.com#Donations
